@@ -1,7 +1,7 @@
 package PERLANCAR::HTML::Tree::Examples;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '1.000.001'; # VERSION
+our $DATE = '2016-04-03'; # DATE
+our $VERSION = '1.000.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,7 +14,7 @@ use Exporter::Rinci qw(import);
 
 our %SPEC;
 
-$SPEC{gen_sample_html} = {
+$SPEC{gen_sample_data} = {
     v => 1.1,
     summary => 'Generate sample HTML document',
     description => <<'_',
@@ -44,6 +44,7 @@ element.
 _
             req => 1,
             pos => 0,
+            tags => ['data-parameter'],
         },
     },
     result => {
@@ -51,7 +52,7 @@ _
     },
     result_naked => 1,
 };
-sub gen_sample_html {
+sub gen_sample_data {
     my %args = @_;
 
     my $size = $args{size} or die "Please specify size";
@@ -83,6 +84,8 @@ sub gen_sample_html {
     );
 }
 
+*gen_sample_html = \&gen_sample_data;
+
 1;
 # ABSTRACT: Generate sample HTML document
 
@@ -98,13 +101,13 @@ PERLANCAR::HTML::Tree::Examples - Generate sample HTML document
 
 =head1 VERSION
 
-This document describes version 1.000.001 of PERLANCAR::HTML::Tree::Examples (from Perl distribution PERLANCAR-HTML-Tree-Examples), released on 2016-04-01.
+This document describes version 1.000.002 of PERLANCAR::HTML::Tree::Examples (from Perl distribution PERLANCAR-HTML-Tree-Examples), released on 2016-04-03.
 
 =head1 SYNOPSIS
 
- use PERLANCAR::HTML::Tree::Examples qw(gen_sample_html);
+ use PERLANCAR::HTML::Tree::Examples qw(gen_sample_data);
 
- my $html = gen_sample_html(size => 'medium1');
+ my $html = gen_sample_data(size => 'medium1');
 
 =head1 DESCRIPTION
 
@@ -115,66 +118,66 @@ This document describes version 1.000.001 of PERLANCAR::HTML::Tree::Examples (fr
 =item * size=tiny1
 
  <body data-level="0" id="1">
-  <h1 data-level="1" id="2">
-  </h1>
-  <h1 data-level="1" id="3">
-  </h1>
-</body>
+   <h1 data-level="1" id="2">
+   </h1>
+   <h1 data-level="1" id="3">
+   </h1>
+ </body>
 
 =item * size=small1
 
  <body data-level="0" id="1">
-  <h1 data-level="1" id="2">
-    <h2 data-level="2" id="3">
-      <h3 data-level="3" id="4">
-      </h3>
-      <h3 data-level="3" id="5">
-      </h3>
-      <h3 data-level="3" id="6">
-        <h4 data-level="4" id="7">
-        </h4>
-      </h3>
-      <h3 data-level="3" id="8">
-      </h3>
-    </h2>
-  </h1>
-  <h1 data-level="1" id="9">
-  </h1>
-  <h1 data-level="1" id="10">
-    <h2 data-level="2" id="11">
-      <h3 data-level="3" id="12">
-(... 12 more line(s) not shown ...)
+   <h1 data-level="1" id="2">
+     <h2 data-level="2" id="3">
+       <h3 data-level="3" id="4">
+       </h3>
+       <h3 data-level="3" id="5">
+       </h3>
+       <h3 data-level="3" id="6">
+         <h4 data-level="4" id="7">
+         </h4>
+       </h3>
+       <h3 data-level="3" id="8">
+       </h3>
+     </h2>
+   </h1>
+   <h1 data-level="1" id="9">
+   </h1>
+   <h1 data-level="1" id="10">
+     <h2 data-level="2" id="11">
+       <h3 data-level="3" id="12">
+ (... 12 more line(s) not shown ...)
 
 =item * size=medium1
 
  <body data-level="0" id="1">
-  <h1 data-level="1" id="2">
-    <h2 data-level="2" id="3">
-      <h3 data-level="3" id="4">
-        <h4 data-level="4" id="5">
-        </h4>
-        <h4 data-level="4" id="6">
-          <h5 data-level="5" id="7">
-          </h5>
-        </h4>
-      </h3>
-      <h3 data-level="3" id="8">
-        <h4 data-level="4" id="9">
-        </h4>
-      </h3>
-    </h2>
-    <h2 data-level="2" id="10">
-      <h3 data-level="3" id="11">
-        <h4 data-level="4" id="12">
-          <h5 data-level="5" id="13">
-(... 40782 more line(s) not shown ...)
+   <h1 data-level="1" id="2">
+     <h2 data-level="2" id="3">
+       <h3 data-level="3" id="4">
+         <h4 data-level="4" id="5">
+         </h4>
+         <h4 data-level="4" id="6">
+           <h5 data-level="5" id="7">
+           </h5>
+         </h4>
+       </h3>
+       <h3 data-level="3" id="8">
+         <h4 data-level="4" id="9">
+         </h4>
+       </h3>
+     </h2>
+     <h2 data-level="2" id="10">
+       <h3 data-level="3" id="11">
+         <h4 data-level="4" id="12">
+           <h5 data-level="5" id="13">
+ (... 40782 more line(s) not shown ...)
 
 =back
 
 =head1 FUNCTIONS
 
 
-=head2 gen_sample_html(%args) -> str
+=head2 gen_sample_data(%args) -> str
 
 Generate sample HTML document.
 
@@ -207,6 +210,8 @@ C<medium1> is a document of depth 7 and ~20k elements.
 
 Return value:  (str)
 
+=for Pod::Coverage ^(gen_sample_html)$
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-HTML-Tree-Examples>.
